@@ -7,5 +7,6 @@
                            "seslope", "slope", "weekday", "cuts", "empty",
                            "lat", "lon", "traj_len", "wkday", "date_end",
                            "validity", "process", "parameter", "date_start",
-                           "site", "where", "ratified_to", "site_type", "start_date"))
+                           "site", "where", "ratified_to", "site_type", "start_date",
+                           "u", "v", "period", "z", "wd", "cluster", ".id"))
 }
